/* *********************************************************************** 
** From SQL Server Magazine - September 2003
** Recovering from Isolated Corruption
** Use this script to SETUP for the PARTIAL and STANDBY options
** used to investigate damaged databases.

** NOTE: This script is best viewed in Courier New 12pt
*********************************************************************** */

/* *********************************************************************** 
** This script will create another copy of the Pubs database named
** PubsTest. PubsTest will be created in the default location of SQL
** SQL Server on drive c:\. Change C:\Program Files\Microsoft SQL 
** Server\mssql\data\ if you did NOT install SQL Server in the default 
** directory and/or path. Make sure you MODIFY this script before 
** running it. 
** 
** In addition to copying Pubs to the new PubsTest database, this script 
** will add 5 files TOTALLING 30 MB of additional space. In all this 
** script requires roughly 40 MB of space.
** 
** Once PubsTest has been created it is modified and backed up. 

** Have fun,
** kt
*********************************************************************** */

-- DROP DATABASE NewPubsTest
-- DROP DATABASE PubsTest

USE pubs
go

BACKUP DATABASE [pubs] 
	TO DISK = N'C:\Program Files\Microsoft SQL Server\MSSQL\BACKUP\pubsbackup.dat' WITH INIT
go

RESTORE DATABASE [PubsTest] 
	FROM  DISK = N'C:\Program Files\Microsoft SQL Server\MSSQL\BACKUP\pubsbackup.dat' 
	WITH  FILE = 1,  NOUNLOAD ,  STATS = 10,  RECOVERY ,  
MOVE N'pubs_log' TO N'C:\Program Files\Microsoft SQL Server\MSSQL\DATA\PubsTestLog.ldf',  
MOVE N'pubs' TO N'C:\Program Files\Microsoft SQL Server\MSSQL\data\PubsTest.mdf'
go

ALTER DATABASE [PubsTest] 
	SET RECOVERY FULL
go

USE [PubsTest] 
go

-- Increase the size of the Transaction Log for later activity
ALTER DATABASE [PubsTest] 
MODIFY FILE
		(NAME = N'pubs_log', 
		SIZE = 7, FILEGROWTH = 10%)
go

-- Add Additional Files and a FileGroup.
ALTER DATABASE [PubsTest] ADD FILEGROUP [RWFG] 
go

ALTER DATABASE [PubsTest] 
	ADD FILE
		(NAME = N'PubsTestRWFile1', 
		FILENAME = N'c:\Program Files\Microsoft SQL Server\MSSQL\data\PubsTestRWFile1.NDF' , 
		SIZE = 6, FILEGROWTH = 10%) 
		TO FILEGROUP [RWFG]
go
ALTER DATABASE [PubsTest] 
	ADD FILE
		(NAME = N'PubsTestRWFile2', 
		FILENAME = N'c:\Program Files\Microsoft SQL Server\MSSQL\data\PubsTestRWFile2.NDF' , 
		SIZE = 6, FILEGROWTH = 10%) 
		TO FILEGROUP [RWFG]
go
ALTER DATABASE [PubsTest] 
	ADD FILE
		(NAME = N'PubsTestRWFile3', 
		FILENAME = N'c:\Program Files\Microsoft SQL Server\MSSQL\data\PubsTestRWFile3.NDF' , 
		SIZE = 6, FILEGROWTH = 10%) 
		TO FILEGROUP [RWFG]
go
ALTER DATABASE [PubsTest] ADD FILEGROUP [ROFG] 
go

ALTER DATABASE [PubsTest] 
	ADD FILE
		(NAME = N'PubsTestROFile1', 
		FILENAME = N'c:\Program Files\Microsoft SQL Server\MSSQL\data\PubsTestROFile1.NDF' , 
		SIZE = 5, FILEGROWTH = 10%) 
		TO FILEGROUP [ROFG]
go
ALTER DATABASE [PubsTest] 
	ADD FILE
		(NAME = N'PubsTestROFile2', 
		FILENAME = N'c:\Program Files\Microsoft SQL Server\MSSQL\data\PubsTestROFile2.NDF' , 
		SIZE = 5, FILEGROWTH = 10%) 
		TO FILEGROUP [ROFG]
go

USE PubsTest
go
sp_helpfile -- To Review the current number of and size of the database files.
go
ALTER DATABASE PubsTest
	MODIFY FILEGROUP [RWFG] DEFAULT
-- This allows you to place objects on the Filegroup WITHOUT specifying it every time!
go

CREATE TABLE dbo.DemoTable
(
	col1	int	 identity(100,10),
	col2	datetime default current_timestamp,
	col3	datetime default getdate(),
	col4	char(30) default suser_name(),
	col5	char(30) default user_name(),
	col6	char(80) default 'Now is the time for all good men to come to the aid of their country.'
) -- ON [RWFG] -- this is NOT required if RWFG is the DEFAULT FileGroup.
go

SELECT count(*) FROM dbo.DemoTable	-- 0 Rows but the table does exist.
go

SET NOCOUNT ON
DECLARE @RowCounter	int
SELECT @RowCounter = 1
WHILE @RowCounter < 2001
	BEGIN
		INSERT dbo.DemoTable DEFAULT VALUES
		SELECT @RowCounter = @RowCounter + 1
	END
go

BACKUP DATABASE PubsTest 
	TO DISK = N'C:\Program Files\Microsoft SQL Server\MSSQL\BACKUP\PubsTestBackup.dat' 
	WITH INIT
go

-- This batch will execute for roughly 3.5 minutes.
SET NOCOUNT ON
DECLARE @RowCounter	int
SELECT @RowCounter = 1
WHILE @RowCounter < 201
	BEGIN
		WAITFOR DELAY '00:00:01.00'
		INSERT dbo.DemoTable DEFAULT VALUES
		SELECT @RowCounter = @RowCounter + 1
	END
go

BACKUP LOG PubsTest 
	TO DISK = N'C:\Program Files\Microsoft SQL Server\MSSQL\BACKUP\PubsTestBackup.dat' 
	WITH NOINIT
go

-- This batch will execute for roughly 3.5 minutes.
SET NOCOUNT ON
DECLARE @RowCounter	int
SELECT @RowCounter = 1
WHILE @RowCounter < 201
	BEGIN
		WAITFOR DELAY '00:00:01.00'
		INSERT dbo.DemoTable DEFAULT VALUES
		SELECT @RowCounter = @RowCounter + 1
	END
go

BACKUP DATABASE PubsTest 
	TO DISK = N'C:\Program Files\Microsoft SQL Server\MSSQL\BACKUP\PubsTestBackup.dat' 
	WITH DIFFERENTIAL, NOINIT
go

SET NOCOUNT ON
DECLARE @RowCounter	int
SELECT @RowCounter = 1
WHILE @RowCounter < 201
	BEGIN
		WAITFOR DELAY '00:00:01.00'
		INSERT dbo.DemoTable DEFAULT VALUES
		SELECT @RowCounter = @RowCounter + 1
	END
go

BACKUP LOG PubsTest 
	TO DISK = N'C:\Program Files\Microsoft SQL Server\MSSQL\BACKUP\PubsTestBackup.dat' 
	WITH NOINIT
go

